========
Codebots
========

.. image:: https://github.com/franaudo/codebots/actions/workflows/docs.yml/badge.svg
        :target: https://github.com/franaudo/codebots/actions/workflows/docs.yml
        :alt: Documentation Status

.. image:: https://github.com/franaudo/codebots/actions/workflows/python-package.yml/badge.svg
        :target: https://github.com/franaudo/codebots/actions/workflows/python-package.yml
        :alt: Python package

.. image:: https://github.com/franaudo/codebots/actions/workflows/codeql-analysis.yml/badge.svg
        :target: https://github.com/franaudo/codebots/actions/workflows/codeql-analysis.yml
        :alt: CodeQL


This is a collection of simple bots to help with boring tasks during coding.

Currently supported bots:

* EmailBot: useful to get an email when a task is complete
* SlackBot: same thing, but you get a slack message instead.
* TeleBot: again the same thing, but you get a message on Telegram this time.
* sshBot: this is different...it will help you with ssh stuff.

Full documentation: https://franaudo.github.io/codebots/latest/.

WIP
---

This pacakge is a WIP! Expect things to be very different among versions. However,
the stable releases will always work and pass all the tests.

If you want to access the latest functionalities, clone the GitHub repo and switch
to the `develop` branch, although it is very likely that things won't work! :)

Features
--------

* Free software: MIT license
* Easy to use
* Fun (well, for someone...)

Credits
~~~~~~~

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
